<?php

/**
 * Rentware
 *
 * @package           rentware
 * @author            Paul Felgentreff https://rentware.com
 * @copyright         Copyright (C) Rentware
 * @license           GNU General Public License version 3, see LICENSE.txt
 *
 * @wordpress-plugin
 * Plugin Name:       Rentware Widgets Shortcodes
 * Tags:              Booking Widget, Rentware
 * Description:       Shortcodes to display Rentware booking widgets.
 * Version:           1.0.0
 * Requires at least: 5.4
 * Requires PHP:      7.3
 * Author:            Rentware
 * Author URI:        https://rentware.com
 * Text Domain:       rentware-widgets-shortcodes
 * License:           GNU General Public License version 3
 * License URI:       https://gnu.org/licenses/gpl-3.0
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

function rw_article( $atts = [] ) {
    // normalize attribute keys, lowercase
    $atts = array_change_key_case( (array) $atts, CASE_LOWER );
 
    // override default attributes with user attributes
    $rw_atts = shortcode_atts(
        array(
            'id' => null,
            'view' => 'default',
        ), $atts
    );
	if ( is_null( $rw_atts['id'] ) ) {
    	return;
	}
    // rw Widget
    $o = '<rentware-article view="' . esc_attr( $rw_atts['view'] ) . '" article-id="' . esc_attr( $rw_atts['id'] ) . '"></rentware-article>';
 
	return $o;
}

function rw_article_booking( $atts = [] ) {
    // normalize attribute keys, lowercase
    $atts = array_change_key_case( (array) $atts, CASE_LOWER );
 
    // override default attributes with user attributes
    $rw_atts = shortcode_atts(
        array(
            'id' => null,
            'view' => 'default',
            'max_width' => '420',
        ), $atts
    );
	if ( is_null( $rw_atts['id'] ) ) {
    	return;
	}
	
    // start box
    $o = '<div style="max-width: ' . esc_attr( $rw_atts['max_width'] ) . 'px; margin: auto;">';
 
    // rw Widget
    $o .= '<rentware-article-booking view="' . esc_attr( $rw_atts['view'] ) . '" article-id="' . esc_attr( $rw_atts['id'] ) . '"></rentware-article-booking>';

    // end box
    $o .= '</div>';
 
	return $o;
}

function rw_search( $atts = [] ) {
    // normalize attribute keys, lowercase
    $atts = array_change_key_case( (array) $atts, CASE_LOWER );
 
    // override default attributes with user attributes
    $rw_atts = shortcode_atts(
        array(
            'view' => 'default',
            'show_location' => '',
            'search_results' => '',
            'results_on_scroll' => '5',
            'hide_results' => 'false',
            'show_only_tags' => '',
            'link_to' => '',
            'locations' => '',
        ), $atts
    );
    // rw Widget
    $o = '<rentware-search view="' . esc_attr( $rw_atts['view'] ) . '" show-location="' . esc_attr( $rw_atts['show_location'] ) . '" search-results="' . esc_attr( $rw_atts['search_results'] ) . '" results-on-scroll="' . esc_attr( $rw_atts['results_on_scroll'] ) . '" hide-results="' . esc_attr( $rw_atts['hide_results'] ) . '" show-only-tags="' . esc_attr( $rw_atts['show_only_tags'] ) . '" link-to="' . esc_url( $rw_atts['link_to'] ) . '" locations="' . esc_attr( $rw_atts['locations'] ) . '"></rentware-search>';

	return $o;
}

function rw_Giftcard( $atts = [] ) {
    // normalize attribute keys, lowercase
    $atts = array_change_key_case( (array) $atts, CASE_LOWER );
 
    // override default attributes with user attributes
    $rw_atts = shortcode_atts(
        array(
            'fixed_amount' => '50',
        ), $atts
    );
    // rw Widget
    $o = '<rentware-giftcard fixed-amount=' . esc_attr( $rw_atts['fixed_amount'] ) . '"></rentware-giftcard>';

	return $o;
}

function rw_shortcodes_init() {
	add_shortcode('rwArticle', 'rw_article');
	add_shortcode('rwArticleBooking', 'rw_article_booking');
	add_shortcode('rwSearch', 'rw_search');
	add_shortcode('rwGiftcard', 'rw_Giftcard');
}
 
add_action( 'init', 'rw_shortcodes_init' );

?>